@@ -76,6 +76,9 @@ class Preferences(object):
     listItemSpacer = u' '
         string which is used in ``css.SelectorList``, ``css.CSSValue`` and
         ``stylesheets.MediaList`` after the comma
+    minimizeColorHash = True
+        defines if colorhash should be minimized from full size to shorthand
+        e.g minimize #FFFFFF to #FFF
     normalizedVarNames = True
         defines if variable names should be serialized normalized (they are
         used as being normalized anyway)
@@ -138,6 +141,7 @@ class Preferences(object):
         self.lineNumbers = False
         self.lineSeparator = '\n'
         self.listItemSpacer = ' '
+        self.minimizeColorHash = True
         self.normalizedVarNames = True
         self.omitLastSemicolon = True
         self.omitLeadingZero = False
@@ -163,6 +167,7 @@ class Preferences(object):
         self.lineNumbers = False
         self.lineSeparator = ''
         self.listItemSpacer = ''
+        self.minimizeColorHash = True
         self.omitLastSemicolon = True
         self.omitLeadingZero = True
         self.paranthesisSpacer = ''
@@ -349,13 +354,13 @@ class CSSSerializer(object):
         """
         Short form of hash, e.g. #123 instead of #112233
         """
-        # TODO: add pref for this!
-        if len(val) == 7 and val[1] == val[2] and\
-                             val[3] == val[4] and\
-                             val[5] == val[6]:
-            return '#%s%s%s' % (val[1], val[3], val[5])
-        else:
-            return val
+        if self.prefs.minimizeColorHash and\
+            len(val) == 7 and\
+            val[1] == val[2] and\
+            val[3] == val[4] and\
+            val[5] == val[6]:
+                return '#%s%s%s' % (val[1], val[3], val[5])
+        return val
 
     def _valid(self, x):
         "checks items valid property and prefs.validOnly"
